# telepot-x - Python framework for Telegram Bot API

## On the basis of telepot, we have updated and fixed some errors. Since the original version has not been updated for a long time and does not accept updates, a new version of telepot-x ​​has been released. If you have installed telepot, it cannot be used. Please uninstall telepot. Use later

### [Introduction »](http://telepot.readthedocs.io/en/latest/)
### [Reference »](http://telepot.readthedocs.io/en/latest/reference.html)
### [Examples »](https://github.com/nickoala/telepot/tree/master/examples)
### [Changelog »](https://github.com/nickoala/telepot/blob/master/CHANGELOG.md)
